popdata: popdata

Description Usage Arguments Value Author(s)

View source: R/popdata.R

Description

R client for UNHCR popdata

Popdata figures

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
popdata(
  report = c("asr", "mysr", "pf"),
  table = c("refugees", "refugeeLike", "returnees", "demographics", "idp", "rsd",
    "stateless", "vda", "other", "hostcommunity", "coo", "ppg", "specific"),
  year = 2020,
  quiet = getOption("popdata_quiet")
)

pd_asr(
  table = c("refugees", "refugeelike", "refugeeLike", "returnees", "demographics",
    "idp", "rsd", "stateless", "vda", "other", "hostcommunity", "hostCommunity"),
  year = 2020,
  quiet = getOption("popdata_quiet")
)

pd_mysr(
  table = c("refugees", "returnees", "idp", "rsd", "stateless", "other"),
  year = 2020,
  quiet = getOption("popdata_quiet")
)

pd_pf(
  table = c("coo", "ppg", "specific"),
  year = 2020,
  quiet = getOption("popdata_quiet")
)

Arguments

report

character, the type of report asr, mysr or pf

table

character, the indicator refugees, refugeeLike, returnees, demographics, idp, rsd, stateless, vda, other, hostcommunity, coo, ppg or specifics

year

integer, the year

quiet

logical, print message on updating session cookie or not. options(popdata_quiet = TRUE) can also be used

Value

A tibble

Author(s)

mail@ahmadoudicko.com


dickoa/popdata documentation built on March 14, 2021, 12:46 p.m.