popdata: popdata() function by Fang Jiang This function takes input...

Description Usage

View source: R/popdata.R

Description

popdata() function by Fang Jiang This function takes input from the user on allele names and population size It then prints out the genetic variation data

Usage

1
popdata(allele1, allele2, popsize)

fangjiang99/popdata documentation built on Dec. 20, 2021, 7:42 a.m.