popdata() function by Fang Jiang This function takes input from the user on allele names and population size It then prints out the genetic variation data
1 | popdata(allele1, allele2, popsize)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.